Function compress_project

pub fn compress_project(
    path: &Path,
    compression: Compression,
    deterministic: bool,
    naive: bool,
    hash: bool,
    size_limit_mb: u32,
) -> Result<(Vec<u8>, Option<Hash>), PluginError>
Compresses the directory at the given path, only including student files unless naive is set to true.